View Source GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCalendarEventAttendee (google_api_content_warehouse v0.4.0)
Next id: 8
Attributes
-
displayName(type:String.t, default:nil) - Display name, present only if available. -
email(type:String.t, default:nil) - Email address of the attendee (calendar), for regular events. For +Events, this field is not populated, instead "id" is used. -
givenName(type:String.t, default:nil) - Given (first) name, present only if available. This is used for generating meeting titles as given name is preferred over display (full) name (ie: "Jeff : Sundar" is better than "Jeff Dean : Sundar Pichai"). -
id(type:String.t, default:nil) - Profile ID of the principal, for +Events. For regular events, this field is not populated, instead "email" is used. -
organizer(type:boolean(), default:nil) - Is this the organizer? -
responseStatus(type:String.t, default:nil) - Attendees response status. -
self(type:boolean(), default:nil) - Is this the owner of this copy of the event?
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
Functions
Unwrap a decoded JSON object into its complex fields.