View Source GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCalendarEventMeetingContact (google_api_content_warehouse v0.4.0)
Next id: 10
Attributes
-
conferenceId(type:String.t, default:nil) - ID that corresponds to in ConferenceData.conference_id in calendar.common.ConferenceData proto. For Meet, this is the identifier used to join a meeting via URL. -
dialInNumberClasses(type:list(String.t), default:nil) - -
phoneNumberUri(type:String.t, default:nil) - Default meeting phone number, for example: "tel:+1-475-777-1840" -
pinNumber(type:String.t, default:nil) - A PIN that the participant will need to input after dialing in the conference. -
provider(type:GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesProvider.t, default:nil) - Provider info for the meeting. -
regionCode(type:String.t, default:nil) - The region code for the default meeting phone number -
source(type:String.t, default:nil) - -
universalPinNumber(type:String.t, default:nil) - The universal meeting PIN number for phone numbers in all available countries -
url(type:String.t, default:nil) - URL that can be used to join the meeting.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCalendarEventMeetingContact{ conferenceId: String.t() | nil, dialInNumberClasses: [String.t()] | nil, phoneNumberUri: String.t() | nil, pinNumber: String.t() | nil, provider: GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesProvider.t() | nil, regionCode: String.t() | nil, source: String.t() | nil, universalPinNumber: String.t() | nil, url: String.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.