View Source GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCloudProviderInfo (google_api_content_warehouse v0.4.0)
The third party provider information.
Attributes
-
agentStyle(type:GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCloudProviderInfoAgentStyle.t, default:nil) - -
directoryUrl(type:String.t, default:nil) - URL to a directory page about the third party agent in Assistant HQ. This is a universal (https) URL that may be handled natively by clients to show HQ or launch to the HQ directory web page. -
logoUrl(type:String.t, default:nil) - The logo url for the third party provider. -
name(type:String.t, default:nil) - The user visible name of the cloud provider, which may be used for example in the chat header during a conversation with the third party.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCloudProviderInfo{ agentStyle: GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesCloudProviderInfoAgentStyle.t() | nil, directoryUrl: String.t() | nil, logoUrl: String.t() | nil, name: String.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.