View Source GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesMessageNotificationNotificationEntry (google_api_content_warehouse v0.4.0)
Structure of each notification in the MessageNotification Bundle. Attribute sender_name could be different in case of group messages. Next Id: 9
Attributes
-
audioDuration(type:String.t, default:nil) - Duration of audio message. -
charCount(type:integer(), default:nil) - Count of characters in the message body in the notification. -
dataUri(type:String.t, default:nil) - Uri for the attachment (image, audio, video etc.). -
messageBody(type:String.t, default:nil) - Note that this is not present in production traffic. Content of the message body in the notification. -
mimeType(type:String.t, default:nil) - Mime type of the data_uri. e.g. 'audio/wav', 'video/mp4', 'image/png'. -
postTime(type:DateTime.t, default:nil) - Timestamp of the notification's post time. -
sender(type:GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesMessageNotificationPerson.t, default:nil) - Sender of the message notification. -
wordCount(type:integer(), default:nil) - Count of words in the message body in the notification.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesMessageNotificationNotificationEntry{ audioDuration: String.t() | nil, charCount: integer() | nil, dataUri: String.t() | nil, messageBody: String.t() | nil, mimeType: String.t() | nil, postTime: DateTime.t() | nil, sender: GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesMessageNotificationPerson.t() | nil, wordCount: integer() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.