View Source GoogleApi.ContentWarehouse.V1.Model.AssistantApiCoreTypesRingtoneTaskMetadataFuntimeMetadata (google_api_content_warehouse v0.4.0)
Used to make timers and alarms more delightful. See go/funtime-engdesign for more details.
Attributes
-
agentIds(type:list(String.t), default:nil) - For FunTime alarms and timers, the media resources are provided through AOG apps during their ringtone. Multiple AoG agents can satisfy a label. So a random agent will be chosen from those that are supplied. See go/funtime-engdesign. -
animationBlob(type:String.t, default:nil) - These bytes may represent the blob of the Rive animation that we pass to the Opal App. We will deprecate this field if we figure out a solution to load the animation from the web. -
animationUrl(type:String.t, default:nil) - Url for Rive animation that is brought up on ring. Rive is a lightweight animation library that is compatible with Flutter on Opal. See https://rive.app/. -
timerHeroUrl(type:String.t, default:nil) - The url used to load the image that is at the center of the timer during timer countdown visuals. -
ttsServiceRequestBytes(type:String.t, default:nil) - This is used to call S3 to realize the TTS. Is in the form of bytes because of a circular dependency issue in libassistant protos. It is a serialized proto of type speech.s3.TtsServiceRequest.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
Functions
Unwrap a decoded JSON object into its complex fields.